@@ -1,11 +1,12 @@
 package Gepok;
 
+our $DATE = '2019-04-24'; # DATE
+our $VERSION = '0.290'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
-
-our $VERSION = '0.27'; # VERSION
+use Log::ger;
 
 use File::HomeDir;
 use HTTP::Daemon::Patch::IPv6;
@@ -18,7 +19,7 @@ use IO::Select;
 use IO::Socket qw(:crlf);
 use Plack::Util;
 use POSIX;
-use SHARYANTO::Proc::Daemon::Prefork;
+use Proc::Daemon::Prefork;
 use Time::HiRes qw(gettimeofday);
 use URI::Escape;
 
@@ -46,7 +47,7 @@ has ssl_cert_file          => (is => 'rw');
 has start_servers          => (is => 'rw', default => sub{3});
 has max_clients            => (is => 'rw', default=>sub{150});
 has max_requests_per_child => (is => 'rw', default=>sub{1000});
-has _daemon                => (is => 'rw'); # SHARYANTO::Proc::Daemon::Prefork
+has _daemon                => (is => 'rw'); # Proc::Daemon::Prefork
 has _server_socks          => (is => 'rw'); # store server sockets
 has _app                   => (is => 'rw'); # store PSGI app
 has product_name           => (is => 'rw');
@@ -86,7 +87,7 @@ sub BUILD {
         die "ssl_verify_callback needs to be a coderef, or constant '1' or '0'" unless ref $vc eq 'CODE';
     }
     unless ($self->_daemon) {
-        my $daemon = SHARYANTO::Proc::Daemon::Prefork->new(
+        my $daemon = Proc::Daemon::Prefork->new(
             name                    => $self->name,
             error_log_path          => $self->error_log_path,
             access_log_path         => $self->access_log_path,
@@ -146,7 +147,7 @@ sub _after_init {
         my %args;
         $args{Timeout} = $self->timeout;
         $args{Local}   = $path;
-        $log->infof("Binding to Unix socket %s (http) ...", $path);
+        log_info("Binding to Unix socket %s (http) ...", $path);
         my $sock = HTTP::Daemon::UNIX->new(%args);
         die "Unable to bind to Unix socket $path: $@" unless $sock;
         push @server_socks, $sock;
@@ -168,7 +169,7 @@ sub _after_init {
             die "Invalid http_port syntax `$port`, please specify ".
                 ":N or 1.2.3.4:N";
         }
-        $log->infof("Binding to TCP socket %s (http) ...", $port);
+        log_info("Binding to TCP socket %s (http) ...", $port);
         my $sock = HTTP::Daemon->new(%args);
         die "Unable to bind to TCP socket $port" unless $sock;
         push @server_socks, $sock;
@@ -204,7 +205,7 @@ sub _after_init {
                 ":N or 1.2.3.4:N";
         }
 
-        $log->infof("Binding to TCP socket %s (https) ...", $port);
+        log_info("Binding to TCP socket %s (https) ...", $port);
         my $sock = HTTP::Daemon::SSL->new(%args);
         die "Unable to bind to TCP socket $port, common cause include ".
             "port taken or missing server key/cert file" unless $sock;
@@ -225,9 +226,9 @@ sub before_prefork {}
 sub _main_loop {
     my ($self) = @_;
     if ($self->_daemon->{parent_pid} == $$) {
-        $log->info("Entering main loop");
+        log_info("Entering main loop");
     } else {
-        $log->info("Child process started (PID $$)");
+        log_info("Child process started (PID $$)");
     }
     $self->_daemon->update_scoreboard({child_start_time=>time()});
 
@@ -393,7 +394,7 @@ sub _write_sock {
             my $written = syswrite $sock, $buffer, length($buffer)-$tot_written,
                 $tot_written;
             # XXX what to do on error, i.e. $written is undef?
-            $tot_written += $written;
+            $tot_written += $written // 0;
             last unless $tot_written < length($buffer);
         }
     }
@@ -504,7 +505,7 @@ sub _set_label_serving {
     if ($is_unix) {
         my $sock_path = $httpd->hostpath;
         my ($pid, $uid, $gid) = $httpd->peercred;
-        $log->trace("Unix socket info: path=$sock_path, ".
+        log_trace("Unix socket info: path=$sock_path, ".
                         "pid=$pid, uid=$uid, gid=$gid");
         $self->_daemon->set_label("serving unix (pid=$pid, uid=$uid, ".
                                       "path=$sock_path)");
@@ -513,8 +514,8 @@ sub _set_label_serving {
         my $server_port = $sock->sockport;
         my $remote_ip   = $sock->peerhost // "127.0.0.1";
         my $remote_port = $sock->peerport;
-        if ($log->is_trace) {
-            $log->trace(join("",
+        if (log_is_trace) {
+            log_trace(join("",
                              "TCP socket info: https=$is_ssl, ",
                              "server_port=$server_port, ",
                              "remote_ip=$remote_ip, ",
@@ -543,8 +544,8 @@ sub access_log {
     return unless $self->access_log_path;
 
     my $reqh = $req->headers;
-    if ($log->is_trace) {
-        $log->tracef("\$self->{_sock_peerhost}=%s, (gmtime(\$self->{_finish_req_time}))[0]=%s, \$req->method=%s, \$req->uri->as_string=%s, \$self->{_res_status}=%s, \$self->{res_content_length}=%s, ".
+    if (log_is_trace) {
+        log_trace("\$self->{_sock_peerhost}=%s, (gmtime(\$self->{_finish_req_time}))[0]=%s, \$req->method=%s, \$req->uri->as_string=%s, \$self->{_res_status}=%s, \$self->{res_content_length}=%s, ".
                          "\$reqh->header('referer')=%s, \$reqh->header('user-agent')=%s",
                      $self->{_sock_peerhost},
                      (gmtime($self->{_finish_req_time}))[0],
@@ -593,13 +594,17 @@ Gepok - PSGI server with built-in HTTPS support, Unix sockets, preforking
 
 =head1 VERSION
 
-This document describes version 0.27 of Gepok (from Perl distribution Gepok), released on 2014-06-03.
+This document describes version 0.290 of Gepok (from Perl distribution Gepok), released on 2019-04-24.
 
 =head1 SYNOPSIS
 
 To run with plackup:
 
- % plackup -s Gepok --daemonize
+ % plackup -s Gepok \
+     --http_ports :8081,:8082,127.0.0.1:8083 \
+     --unix_sockets /var/run/gepok.sock,/tmp/gepok.sock \
+     ...
+     --daemonize
 
 To run standalone:
 
@@ -642,10 +647,6 @@ Good performance and reliability.
 
 Gepok can run under B<plackup>, or standalone.
 
-This module uses L<Log::Any> for logging.
-
-This module uses L<Moo> for object system.
-
 =head1 PSGI ENVIRONMENT
 
 Gepok adds the following server-specific keys in the PSGI environment passed to
@@ -688,6 +689,10 @@ $env->{'gepok.socket'}).
 
 =back
 
+=head1 CREDITS
+
+Some code portion taken from Starman.
+
 =head1 ATTRIBUTES
 
 =head2 name => STR (default is basename of $0)
@@ -729,7 +734,7 @@ Socket timeout. Will be passed as Timeout option to HTTP::Daemon's constructor
 
 Whether to require running as root.
 
-Passed to SHARYANTO::Proc::Daemon::Prefork's constructor.
+Passed to Proc::Daemon::Prefork's constructor.
 
 =head2 pid_path => STR (default /var/run/<name>.pid or ~/<name>.pid)
 
@@ -901,9 +906,21 @@ At the time of this writing, L<HTTP::Daemon> (6.01) might throw this error
 message when receiving request. For patches/solutions to overcome this problem,
 see: https://rt.cpan.org/Ticket/Display.html?id=71395
 
-=head1 CREDITS
+=head1 HOMEPAGE
 
-Some code portion taken from Starman.
+Please visit the project's homepage at L<https://metacpan.org/release/Gepok>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-Gepok>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Gepok>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 SEE ALSO
 
@@ -932,29 +949,13 @@ balancer.
 
 Please drop me a message if you think other PSGI servers need to be mentioned.
 
-=head1 HOMEPAGE
-
-Please visit the project's homepage at L<https://metacpan.org/release/Gepok>.
-
-=head1 SOURCE
-
-Source repository is at L<https://github.com/sharyanto/perl-Gepok>.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Gepok>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2019, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
